ActiveAdmin.register ActiveadminCms::Page, as: 'Page' do
  menu parent: "CMS"
  filter :title
  filter :category
  
  action_item only: :show do
    if page.has_unpublished_changes? || !page.published?
      link_to "Publish", publish_admin_page_path, method: :put
    elsif page.published?
      link_to "Move draft", draft_admin_page_path, method: :put
    end
  end

  index do
    column :id
    column :category
    column :title do |page|
      if page.has_unpublished_changes?
        "* #{page.title}"
      else
        page.title
      end
    end
    column :created_at
    default_actions
  end

  show do
    panel "Post Details" do
      attributes_table_for page do
        row(:url) do |page|
          link_to "/#{page.slug}", "/#{page.slug}", target: '_blank'
        end
        row(:published?)
        row(:has_unpublished_changes?)
        row(:created_at)
      end
    end
    active_admin_comments
  end

  controller do
    def create
      @page = ActiveadminCms::Page.new
      save_page(@page)
    end

    def update
      @page = ActiveadminCms::Page.find(params[:id])
      save_page(@page)
    end

    def save_page(page)
      page_params = permitted_params[:page]
      asset_ids_str = page_params.delete(:asset_ids).to_s
      puts asset_ids_str.gsub(/[\[\]]*/, '').split(',').map(&:strip).map(&:to_i)
      page.asset_ids = asset_ids_str.gsub(/[\[\]]*/, '').split(',').map(&:strip).map(&:to_i)
      page.attributes = page_params
      if page.save
        if params[:commit].downcase != 'save'
          ActiveadminCms::PagesService.publish(page)
        end
        redirect_to admin_page_path(page)
      else
        render (page.new_record? ? :new : :edit)
      end
    end
  end

  form partial: "form"

  controller do
    def permitted_params
      params.permit page: [
        :draft_content, :draft_js_content, :draft_css_content, 
        :title, :category, :asset_ids, :slug
      ]
    end
  end

  member_action :publish, method: :put do
    page = ActiveadminCms::Page.find(params[:id])
    ActiveadminCms::PagesService.publish(page)
    redirect_to admin_page_path(page), notice: "The page has been published!"
  end

  member_action :draft, method: :put do
    page = ActiveadminCms::Page.find(params[:id])
    ActiveadminCms::PagesService.move_draft(page)
    redirect_to admin_page_path(page), notice: "The page has been moved to draft!"
  end
end
