ActiveAdmin.register ActiveadminCms::Post, as: 'Post' do
  menu parent: "CMS"
  filter :title

  action_item only: :show do
    if !post.published?
      link_to "Publish", publish_admin_post_path, method: :put
    elsif post.published?
      link_to "Move draft", draft_admin_post_path, method: :put
    end
  end

  index do
    column :id
    column :title
    column :created_at
    default_actions
  end

  show do
    panel "Post Details" do
      attributes_table_for post do
        row(:title)
        row(:content)
        row(:published)
        row(:created_at)
      end
    end
    active_admin_comments
  end

  form do |f|
    f.inputs "Details" do
      f.input :title
      f.input :content
      if ActiveadminCms::Engine.config.tags_backend = 'acts_as_taggable_on'
        f.input :tag_list
      end
    end
    f.actions
  end

  controller do
    def permitted_params
      params.permit post: [:title, :content, :tag_list]
    end
  end

  member_action :publish, method: :put do
    post = ActiveadminCms::Post.find(params[:id])
    ActiveadminCms::PostsService.publish(post)
    redirect_to admin_post_path(post), notice: "The post has been published!"
  end

  member_action :draft, method: :put do
    post = ActiveadminCms::Post.find(params[:id])
    ActiveadminCms::PostsService.move_draft(post)
    redirect_to admin_post_path(post), notice: "The post has been moved to draft!"
  end
end
