module ActiveadminCms
  class ComposerService < Cyrax::Base
    class << self
      def render(html, &block)
        self.new(html).render(&block)
      end
    end

    def initialize(html = nil)
      @html = html
      @options = {}
      @processors = []
    end

    def render(&block)
      block.call(self) if block_given?
      render!
    end

    def render!
      processor_classes.each do |processor_class|
        @html = processor_class.new(@html, @options).process!
      end
      @html
    end

    def process_with(processor)
      @processors << processor
    end
    alias_method :process, :process_with

    def assign(option, value)
      @options[option.to_sym] = value
    end

    private

    def processor_classes
      @processors.map do |processor|
        "ActiveadminCms::Processors::#{processor.to_s.camelize}".constantize
      end
    end
  end
end
